@@ -96,6 +96,15 @@ def get_current_user(token: str = Depends(oath2_scheme)):
         raise DoormanAuthException(message=e)
 
 
+@need_firestore
+def get_current_email_user(token: str = Depends(oath2_scheme)):
+    try:
+        decoded = auth.verify_id_token(token)
+        return decoded
+    except firebase_admin._token_gen.ExpiredIdTokenError as e:
+        raise DoormanAuthException(message=e)
+
+
 GET_USER = Depends(get_current_user)
 
 g.app.include_router(doorman_router, prefix=doorman_prefix, tags=["Doorman"])
